@@ -58,18 +58,13 @@ Game::Game() :
     // Create the Maze instance
     m_maze = new Maze();
     connect(m_maze, &Maze::allElementsEaten, this, &Game::nextLevel);
-
     // Create the parser that will parse the XML file in order to initialize the Maze instance
     // This also creates all the characters
     KapmanParser kapmanParser(this);
     // Set the XML file as input source for the parser
     QFile mazeXmlFile(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("defaultmaze.xml")));
-    QXmlInputSource source(&mazeXmlFile);
-    // Create the XML file reader
-    QXmlSimpleReader reader;
-    reader.setContentHandler(&kapmanParser);
-    // Parse the XML file
-    reader.parse(source);
+    mazeXmlFile.open(QIODevice::ReadOnly);
+    kapmanParser.parse(&mazeXmlFile);
 
     connect(m_kapman, &Kapman::sWinPoints, this, &Game::winPoints);
 
